@@ -513,12 +513,9 @@ _wnck_get_atom_list (Screen  *screen,
       return FALSE;
     }
 
-  if (nitems != 0)
-    {
-      *atoms = g_new (Atom, nitems);
-      memcpy (*atoms, data, sizeof (Atom) * nitems);
-      *len = nitems;
-    }
+  *atoms = g_new (Atom, nitems);
+  memcpy (*atoms, data, sizeof (Atom) * nitems);
+  *len = nitems;
 
   XFree (data);
 
